﻿function BaseController(name) {
    this.Name = name;
    this.IsReady = false;
    this.FormOrder = {};
}

BaseController.prototype.Initialize = function (callback) {
    this.IsReady = true;
    if (callback) callback(this);
}

BaseController.prototype.InitializePageScroller = function (pageId) {
    this[pageId + "Scroller"] = new BaseControllerScroller(pageId);
}

BaseController.prototype.RefreshFormData = function (pageId, actionCallback, visible) {
    var arr = $("#" + pageId + " :input[tabindex]:not('[disabled=disabled],[readonly=readonly]')");
    if (visible) arr = arr.filter(":visible");
    this.FormOrder[pageId] = arr.sort(function (a, b) {
        return a.tabIndex - b.tabIndex;
    });
    this.FormOrder[pageId].ActionCallback = actionCallback;
    this.FormOrder[pageId].Controller = this;
    this.FormOrder[pageId].PageID = pageId;
}

BaseController.prototype.InitializeForm = function (pageId, actionCallback) {
    this.RefreshFormData(pageId, actionCallback, false);
    $("#" + pageId).on("keydown", ":input[tabindex]:not('[disabled=disabled],[readonly=readonly]')", this, function (e) {
        if (e.which == 13) {
            e.data = e.data.FormOrder[pageId];
            e.preventDefault();
            var index = -1;
            for (var i = 0; i < e.data.length; i++) {
                if (e.data[i].id == this.id) {
                    index = i;
                    break;
                }
            }
            if (index > -1) {
                index++;
                if (index < e.data.length) {
                    e.data.Controller.ScrollPageToInput(e.data.PageID, $(e.data[index]), false);
                }
                else {
                    if (e.data.ActionCallback) e.data.ActionCallback();
                }
            }
        }
    });
    $("#" + pageId).on("focus", ":input[tabindex]:not('[disabled=disabled],[readonly=readonly]')", this, function (e) {
        if (!App.Device.IsAndroid) return;
        e.data = e.data.FormOrder[pageId];
        var index = -1;
        for (var i = 0; i < e.data.length; i++) {
            if (e.data[i].id == this.id) {
                index = i;
                break;
            }
        }
        if ((index > -1) && (index < e.data.length)) {
            e.data.Controller.ScrollPageToInput(e.data.PageID, $(e.data[index]), true);
        }
    });
    $("#" + pageId).on("click", ":input[tabindex]:not('[disabled=disabled],[readonly=readonly]')", this, function (e) {
        if (!App.Device.IsAndroid) return;
        e.data = e.data.FormOrder[pageId];
        var index = -1;
        for (var i = 0; i < e.data.length; i++) {
            if (e.data[i].id == this.id) {
                index = i;
                break;
            }
        }
        if ((index > -1) && (index < e.data.length)) {
            e.data.Controller.ScrollPageToInput(e.data.PageID, $(e.data[index]), false);
        }
    });
}

BaseController.prototype.ScrollPageToInput = function (pageId, element, nofocus) {
    var cont = $("#" + pageId + " .content.ui-content");
    var tp = element.parent();
    if (element.is("select")) tp = tp.parent();
    if (element.is("textarea")) tp = element;
    var contmb = parseInt(cont.css('margin-bottom'));
    if (isNaN(contmb)) contmb = 0;
    if (!nofocus) {
        window.setTimeout(function () { element.focus(); }, 10);
    }
    if (!element.is('[readonly]')) {
        window.setTimeout(function () { element.select(); }, 10);
    }
    if (!App.Device.IsAndroid) return;
    var toExec = function () {
        if (element.is(":focus")) {
            window.setTimeout(function () {
                if (App.Device.IsAndroid) {
                    cont.css("overflow", "hidden");
                    cont.scrollTop(cont.scrollTop() + (tp.offset().top - cont.offset().top) - tp.height() + contmb);
                    cont.css("overflow", "auto");
                }
                cont.scrollTop(cont.scrollTop() + (tp.offset().top - cont.offset().top) - tp.height() + contmb);
            }, 100);
            window.setTimeout(function () { $(window).scrollTop(0); }, 200);
        }
    };
    window.setTimeout(toExec, 300);
    window.setTimeout(toExec, 700);
    window.setTimeout(toExec, 1000);
    window.setTimeout(toExec, 1500);
    window.setTimeout(toExec, 2200);
}

//////////////////////// SCROLLER CLASSES ////////////////////////
function BaseControllerScroller(pageId) {
    this.PageID = pageId;
    this.ContentElement = $("#" + pageId + " .content");
    this.ContentScrollTop = 0;
}

BaseControllerScroller.prototype.LoadContentScroll = function () {
    if ((typeof this.ContentScrollTop !== 'undefined') && !isNaN(this.ContentScrollTop) && this.ContentElement) {
        this.ContentElement.scrollTop(this.ContentScrollTop);
    }
    this.ContentScrollTop = 0;
}

BaseControllerScroller.prototype.SaveContentScroll = function () {
    if (this.ContentElement) {
        this.ContentScrollTop = this.ContentElement.scrollTop();
    }
    else {
        this.ContentScrollTop = 0;
    }
}

BaseControllerScroller.prototype.ResetContentScroll = function () {
    this.ContentScrollTop = 0;
    this.LoadContentScroll();
}