﻿function ContactoController() {
    BaseController.call(this, "Contacto");
}

ContactoController.prototype = Object.create(BaseController.prototype);
ContactoController.prototype.constructor = ContactoController;
App.RegisterController(ContactoController);

ContactoController.prototype.Initialize = function (callback) {
    App.RegisterPageInitializer("ContactoAdherir", this.InitializeContactoAdherir);
    App.RegisterPageInitializer("ContactoSugerir", this.InitializeContactoSugerir);
    App.RegisterPageInitializer("ContactoIndex", this.InitializeContactoIndex);
    BaseController.prototype.Initialize.call(this, callback);
}

ContactoController.prototype.InitializeContactoAdherir = function () {
    $("#ContactoAdherirGo").click(function () {
        App.Contacto.RegisterStore();
        return false;
    });
    BaseController.prototype.InitializeForm.call(App.Contacto, "ContactoAdherir", App.Contacto.RegisterStore);
}

ContactoController.prototype.InitializeContactoSugerir = function () {
    $("#ContactoSugerirGo").click(function () {
        App.Contacto.SuggestStore();
        return false;
    });
    BaseController.prototype.InitializeForm.call(App.Contacto, "ContactoSugerir", App.Contacto.SuggestStore);
}

ContactoController.prototype.InitializeContactoIndex = function () {
    $("#ContactoIndexGo").click(function () {
        App.Contacto.DoContact();
        return false;
    });
    BaseController.prototype.InitializeForm.call(App.Contacto, "ContactoIndex", App.Contacto.DoContact);
}

ContactoController.prototype.ShowRegisterStore = function () {
    this.ResetRegisterStore();
    $.mobile.changePage("#ContactoAdherir");
}

ContactoController.prototype.ResetRegisterStore = function () {
    $("#ContactoAdherirName").val("");
    $("#ContactoAdherirContact").val("");
    $("#ContactoAdherirPhone").val("");
    $("#ContactoAdherirEmail").val("");
    $("#ContactoAdherirAddress").val("");
    $("#ContactoAdherirNotes").val("");
}

ContactoController.prototype.RegisterStore = function () {
    var name = $("#ContactoAdherirName").val();
    var contact = $("#ContactoAdherirContact").val();
    var phone = $("#ContactoAdherirPhone").val();
    var email = $("#ContactoAdherirEmail").val();
    var address = $("#ContactoAdherirAddress").val();
    var notes = $("#ContactoAdherirNotes").val();
    if (!name || name == "" || !contact || contact == "" || !phone || phone == "" || !email || email == "" || !address || address == "") {
        App.Layout.Dialog.Alert.Open("Error", "Completá todos los campos requeridos para continuar");
        return;
    }
    if (email.match(/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z0-9.-]+$/i) == null) {
        App.Layout.Dialog.Alert.Open("Error", "Ingresá una dirección de email válida");
        return;
    }
    App.Layout.Dialog.Loading.Open();
    var data = {
        StoreName: name,
        ContactName: contact,
        Phone: phone,
        Email: email,
        Address: address,
        Comments: notes,
        HasWeb: false
    };
    Utils.PostData("Mobile/Contacto/Adherir", data, function (res, data) {
        if (res) {
            App.Layout.Dialog.Loading.Close(function () {
                if (res && data && data.Success) {
                    App.Layout.ShowToast("<b>Gracias por adherir tu comercio</b><br />Un ejecutivo de cuentas se pondrá en contacto a la brevedad para completar la información necesaria para la inclusión del comercio en Relivery.");
                    App.Home.Show();
                }
                else {
                    if (res && data) App.Layout.Dialog.Alert.Open("Error", data.ErrorMessage);
                }
            });
        }
    });
}

ContactoController.prototype.ShowSuggestStore = function () {
    this.ResetSuggestStore();
    $.mobile.changePage("#ContactoSugerir");
}

ContactoController.prototype.ResetSuggestStore = function () {
    $("#ContactoSugerirName").val("");
    $("#ContactoSugerirPhone").val("");
    $("#ContactoSugerirAddress").val("");
    $("#ContactoSugerirEmail").val("");
    $("#ContactoSugerirNotes").val("");
}

ContactoController.prototype.SuggestStore = function () {
    var name = $("#ContactoSugerirName").val();
    var phone = $("#ContactoSugerirPhone").val();
    var email = $("#ContactoSugerirEmail").val();
    var address = $("#ContactoSugerirAddress").val();
    var notes = $("#ContactoSugerirNotes").val();
    if (!name || name == "" || !phone || phone == "") {
        App.Layout.Dialog.Alert.Open("Error", "Completá todos los campos requeridos para continuar");
        return;
    }
    if (email && email != "" && email.match(/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z0-9.-]+$/i) == null) {
        App.Layout.Dialog.Alert.Open("Error", "Ingresá una dirección de email válida");
        return;
    }
    App.Layout.Dialog.Loading.Open();
    var data = {
        Name: name,
        Phone: phone,
        Email: email,
        Address: address,
        Comments: notes
    };
    Utils.PostData("Mobile/Contacto/Sugerir", data, function (res, data) {
        if (res) {
            App.Layout.Dialog.Loading.Close(function () {
                if (res && data && data.Success) {
                    App.Layout.ShowToast("<b>Gracias por sugerirnos un comercio</b><br />Nos pondremos en contacto con el comercio sugerido para que forme parte de Relivery.");
                    App.Home.Show();
                }
                else {
                    if (res && data) App.Layout.Dialog.Alert.Open("Error", data.ErrorMessage);
                }
            });
        }
    });
}

ContactoController.prototype.ShowContact = function () {
    this.ResetContact();
    $.mobile.changePage("#ContactoIndex");
}

ContactoController.prototype.ResetContact = function () {
    $("#ContactoIndexName").val("");
    $("#ContactoIndexEmail").val("");
    $("#ContactoIndexType").val("");
    $("#ContactoIndexNotes").val("");
    Utils.DataBind(App.Layout.General.ContactType, "ContactoIndexType", true);
}

ContactoController.prototype.DoContact = function () {
    var name = $("#ContactoIndexName").val();
    var email = $("#ContactoIndexEmail").val();
    var type = $("#ContactoIndexType").val();
    var notes = $("#ContactoIndexNotes").val();
    if (!name || name == "" || !email || email == "" || !type || type == "" || !notes || notes == "") {
        App.Layout.Dialog.Alert.Open("Error", "Completá todos los campos requeridos para continuar");
        return;
    }
    if (email && email != "" && email.match(/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z0-9.-]+$/i) == null) {
        App.Layout.Dialog.Alert.Open("Error", "Ingresá una dirección de email válida");
        return;
    }
    App.Layout.Dialog.Loading.Open();
    var data = {
        Name: name,
        Email: email,
        Type: type,
        Comments: notes
    };
    Utils.PostData("Mobile/Contacto/Index", data, function (res, data) {
        if (res) {
            App.Layout.Dialog.Loading.Close(function () {
                if (res && data && data.Success) {
                    App.Layout.ShowToast("<b>Gracias por tu contacto</b><br />Tu mensaje será derivado al sector correspondiente y de ser necesario nos pondremos en contacto a la brevedad.");
                    App.Home.Show();
                }
                else {
                    if (res && data) App.Layout.Dialog.Alert.Open("Error", data.ErrorMessage);
                }
            });
        }
    });
}

ContactoController.prototype.Phone = function () {
    window.location = "tel:6841-9135";
}

ContactoController.prototype.Chat = function () {
    try {
        if (App.IsMobileApp) {
            window.open("http://www.relivery.com.ar/Content/Mobile/Ref/zopimchat.html", "_system");
        }
        else {
            $zopim(function () {
                $zopim.livechat.window.show();
            });
        }
    }
    catch (ex) {
    }
}