﻿function HomeController() {
    BaseController.call(this, "Home");
    this.SearchType = { GPS: 0, Address: 1, Favorite: 2 };
}

HomeController.prototype = Object.create(BaseController.prototype);
HomeController.prototype.constructor = HomeController;
App.RegisterController(HomeController);

HomeController.prototype.Initialize = function (callback) {
    App.RegisterPageInitializer("HomeIndex", this.InitializeHomeIndex);
    App.RegisterPageInitializer("HomeIntro", this.InitializeHomeIntro);
    BaseController.prototype.Initialize.call(this, callback);
}

HomeController.prototype.InitializeHomeIndex = function () {
    Utils.DataBind(App.Layout.General.City, "HomeIndexSearchCity", true);
    App.Home.RefreshHomeIndex();
    $("#HomeIndexFavoritesOption").click(function () {
        $("#HomeIndexOptions").fadeOut();
        $("#HomeIndexFavoritesCont").fadeIn();
        return false;
    });
    $("#HomeIndexFavoritesVolver").click(function () {
        $("#HomeIndexOptions").fadeIn();
        $("#HomeIndexFavoritesCont").fadeOut();
        return false;
    });
    $("#HomeIndexSearchAddressOption").click(function () {
        $("#HomeIndexOptions").fadeOut();
        $("#HomeIndexSearchAddressCont").fadeIn();
        return false;
    });
    $("#HomeIndexSearchAddressVolver").click(function () {
        $("#HomeIndexOptions").fadeIn();
        $("#HomeIndexSearchAddressCont").fadeOut();
        return false;
    });
    $("#HomeIndexFavoritesList").change(function () {
        if ($("#HomeIndexFavoritesList").val() == "add") {
            App.Usuario.ShowDireccion(null, function (res, data) {
                App.Home.Show(true, data.ID);
            });
        }
    });
    $("#HomeIndexFavoritesSearch").click(function () {
        if (App.Authentication.Current.IsAuthenticated && App.Authentication.Current.Addresses) {
            var ao = null;
            $.each(App.Authentication.Current.Addresses, function (i, o) {
                if (o.AddressID == $("#HomeIndexFavoritesList").val()) { ao = o; }
            });
            if (ao == null) return false;
            $("#HomeIndexSearchCity").val(ao.CityName);
            $("#HomeIndexSearchAddress").val(ao.AddressStreet);
            var query = { AddressID: ao.AddressID, City: ao.CityName, Address: ao.AddressStreet };
            App.Home.Search(App.Home.SearchType.Favorite, query);
        }
        return false;
    });
    $("#HomeIndexSearchGPS").click(function () {
        App.Home.Search(App.Home.SearchType.GPS);
        return false;
    });
    $("#HomeIndexSearch").click(function () {
        App.Home.StartAddressSearch();
        return false;
    });
    App.Home.LoadPersistedSearch();
    BaseController.prototype.InitializeForm.call(App.Home, "HomeIndex", App.Home.StartAddressSearch);
}

HomeController.prototype.RefreshHomeIndex = function (dirId) {
    $("#HomeIndexOptions").show();
    $("#HomeIndexSearchAddressCont").hide();
    $("#HomeIndexFavoritesCont").hide();
    var favo = $("#HomeIndexFavoritesOption");
    favo.hide();
    if (App.Authentication.Current && App.Authentication.Current.IsAuthenticated) {
        if (App.Authentication.Current.Addresses.length > 0) {
            var tmp = $("#HomeIndexFavoritesList").val();
            if (tmp == "add") tmp = null;
            if (dirId) tmp = dirId;
            Utils.DataBind(App.Authentication.Current.BindAddresses, "HomeIndexFavoritesList", true);
            $("#HomeIndexFavoritesList").val(tmp);
            $("#HomeIndexFavoritesList").change();
            favo.show();
        }
    }
}

HomeController.prototype.LoadPersistedSearch = function (type, query) {
    var o = Persistence.Get("LastSearch");
    if (o) {
        if (o.Address && o.City) {
            var cityOption = null;
            $("#HomeIndexSearchCity option").each(function () {
                var tmp = $(this).val();
                if (tmp == o.City) cityOption = tmp;
            });
            if (cityOption) {
                var co = $("#HomeIndexSearchCity");
                co.val(cityOption);
                co.change();
                $("#HomeIndexSearchAddress").val(o.Address);
            }
        }
        if (o.AddressID) {
            $("HomeIndexFavoritesList").val(o.AddressID);
        }
    }
}

HomeController.prototype.StartAddressSearch = function () {
    if ($("#HomeIndexSearchAddress").val().trim() == "") {
        App.Layout.Dialog.Alert.Open("Tenés que ingresar una dirección para realizar una búsqueda", "Asegurate de ingresar la dirección en el formato correcto: nombre completo de la calle seguido de la altura (ej: Juan Domingo Perón 3733).");
        return;
    }
    var query = { City: $("#HomeIndexSearchCity").val(), Address: $("#HomeIndexSearchAddress").val() };
    App.Home.Search(App.Home.SearchType.Address, query);
}

HomeController.prototype.Search = function (type, query) {
    App.Layout.Dialog.Searching.Open();
    if (type == this.SearchType.GPS) {
        Utils.GPSLocation(function (result, lat, lon) {
            if (result == true) {
                App.Buscar.DoSearch("", "", lat, lon, null, App.Home.SearchCallback);
            }
            else {
                App.Layout.Dialog.Searching.Close(function () {
                    App.Layout.Dialog.Alert.Open("No se puede determinar la ubicación", "Intenta nuevamente o ingresa tu dirección.");
                });
            }
        });
    }
    else {
        var city = query.City;
        var address = query.Address;
        var addressId = query.AddressID;
        Utils.GeocodeLocation(city, address, function (result, items) {
            if (result == true && items.length == 1) {
                App.Buscar.DoSearch(address, city, items[0].Latitude, items[0].Longitude, addressId, App.Home.SearchCallback);
                return;
            }
            App.Layout.Dialog.Searching.Close(function () {
                if (result == false) {
                    App.Layout.Dialog.Alert.Open("No se encontraron direcciones para la búsqueda ingresada", "Asegurate de ingresar la dirección en el formato correcto: nombre completo de la calle seguido de la altura (ej: Juan Domingo Perón 3733).");
                }
                else {
                    App.Layout.Dialog.Select.Open(
                        "Se encontraron varias direcciones posibles",
                        "Se encontraron varias direcciones posibles para la búsqueda ingresada, por favor seleccioná la correcta.",
                        items, "Address",
                        function (e) {
                            $("#HomeIndexSearchAddress").val(e.data.Address);
                            setTimeout(function () { $("#HomeIndexSearch").click(); }, 1);
                        });
                }
            });
        });
    }
}

HomeController.prototype.SearchCallback = function (res, data) {
    if (res) {
        App.Layout.Dialog.Searching.Close(function () {
            App.Buscar.ShowBuscarIndex();
        });
    }
}

HomeController.prototype.Show = function (noHistory, dirid) {
    this.RefreshHomeIndex(dirid);
    $.mobile.changePage("#HomeIndex", { changeHash: (!noHistory) });
}

HomeController.prototype.InitializeHomeIntro = function () {
    $("#HomeIntroBg").click(function () {
        App.Home.Show();
        return false;
    });
    $("#HomeIntroGo").click(function () {
        if (App.Device.IsAndroid) {
            window.open('https://play.google.com/store/apps/details?id=com.pedidosya&hl=es_419&utm_source=SeMeAntoja%20App&utm_medium=banner&utm_campaign=pedido%20de%20descarga%20de%20PedidosYa%20App', '_system');
        }
        if (App.Device.IsIOS) {
            window.open('https://116070.api-03.com/serve?action=click&publisher_id=116070&site_id=29222&offer_id=337418', '_system');
        }
        if (App.Device.IsWindows) {
            window.open('http://www.pedidosya.com.ar', '_system');
        }
        return false;
    });
}

HomeController.prototype.ShowIntro = function (noHistory) {
    if (!App.Device.IsAndroid && !App.Device.IsIOS && !App.Device.IsWindows) {
        this.Show(noHistory);
        return;
    }
    $.mobile.changePage("#HomeIntro", { changeHash: (!noHistory) });
    setTimeout(function () { $("#HomeIntroGo").css('top', $("#HomeIntroBgImg").height() - $("#HomeIntroGo").height()); }, 750);
}