﻿function LayoutController() {
    BaseController.call(this, "Layout");
    this.Dialog = {};
    this.General = {};
    this.NextToastNotification = null;
    this.UserPanelAction = null;
    this.IsUserPanelOpen = false;
    this.IsCartPanelOpen = false;
}

LayoutController.prototype = Object.create(BaseController.prototype);
LayoutController.prototype.constructor = LayoutController;
App.RegisterController(LayoutController);

LayoutController.prototype.Initialize = function (callback) {
    this.Dialog.Searching = new LayoutControllerSearchingDialog();
    this.Dialog.Alert = new LayoutControllerAlertDialog();
    this.Dialog.Loading = new LayoutControllerLoadingDialog();
    this.Dialog.Select = new LayoutControllerSelectDialog();
    this.InitializeGeneral(callback);
}

LayoutController.prototype.InitializeGeneral = function (callback) {
    $(document).bind('pagechange', function (e, o) {
        if (o.toPage && o.options && o.options.fromPage && o.toPage.attr("id") != o.options.fromPage.attr("id")) {
            App.Layout.DisplayNextToastNotification();
        }
    });
    $(window).on("navigate", function (event, data) {
        if (data && data.state) {
            if (App.Layout.IsUserPanelOpen && data.state.direction == "back") {
                App.Layout.HideUserPanel();
                return;
            }
            if (App.Layout.IsCartPanelOpen && data.state.direction == "back") {
                App.Layout.HideCartPanel();
                return;
            }
            if (data.state.hash == "#LayoutUserPanel" || data.state.hash == "#LayoutCartPanel") {
                if (data.state.direction == "back") {
                    history.go(-1);
                }
            }
        }
    });
//    Utils.GetData("Mobile/Layout/GeneralLookUps", null, function (res, data) {
//        if (res) {
//            for (var i = 0; i < data.length; i++) {
//                App.Layout.General[data[i].Name] = data[i].Data;
//            }
//            BaseController.prototype.Initialize.call(App.Layout, callback);
//        }
//    });
    BaseController.prototype.Initialize.call(App.Layout, callback);
}

LayoutController.prototype.InitializePageLayout = function (pageid) {
    if (!pageid || pageid == "") return;
    $("#" + pageid + " .content").on("swiperight", function () { App.Layout.ShowUserPanel(); });
    $("#" + pageid + " .content").on("swipeleft", function () { App.Layout.ShowCartPanel(); });
    $("#" + pageid + " .header .cart a").on("click", function () { App.Layout.ShowCartPanel(); return false; });
    $("#" + pageid + " .header .options a").on("click", function () { App.Layout.ShowUserPanel(); return false; });
    $("#" + pageid + " .userpanel").on("click", "li.action", function () { App.Layout.UserAction(this); });
    $("#" + pageid + " .userpanel").on("panelclose", function () { App.Layout.HideUserPanelDone(); });
    $("#" + pageid + " .cartpanel").on("panelclose", function () { App.Layout.HideCartPanelDone(); });
    $("#" + pageid + " .cartpanel").on("click", "li.action", function () { App.Pedido.ShowIndex(); });
    $("#" + pageid + " .cartpanel ul.orderdetail").on("click", "table.order td.r div.remove", function () { App.Layout.ShowCartPanel($(this).data("id")); });
    $("#" + pageid + " .header .logo .img").on("click", function () { App.Home.Show(); });
}

LayoutController.prototype.ShowCartPanel = function (removeId) {
    var panel = $.mobile.activePage.find(".cartpanel");
    var wait = $.mobile.activePage.find(".cartpanel .wait")
    var detail = $.mobile.activePage.find(".cartpanel ul.orderdetail")
    var data = null;
    if (removeId) data = { RemoveID: removeId };
    wait.show();
    detail.empty().hide();
    Utils.GetData("Mobile/Layout/SideBarCartPanel", data, function (res, data) {
        if (res) {
            panel.scrollTop(0);
            Utils.DataBind(data, detail, false, false, false, "LayoutCartPanelDetail-Template");
            if (!data.HasItems) {
                if (App.Delivery.Current) {
                    App.Delivery.Current.ShowItemDialogConfirm = false;
                }
            }
            wait.hide();
            detail.show();
            if ($.mobile.activePage.attr("id") == "PedidoIndex") {
                App.Pedido.UpdateOrder(false);
            }
        }
    });
    panel.panel("open");
    this.IsCartPanelOpen = true;
    $.mobile.navigate("#LayoutCartPanel");
}

LayoutController.prototype.ShowUserPanel = function () {
    var panel = $.mobile.activePage.find(".userpanel");
    panel.scrollTop(0);
    Utils.DataBind(App.Authentication.Current, panel, false, false, false, "LayoutUserPanel-Template");
    panel.panel("open");
    this.IsUserPanelOpen = true;
    $.mobile.navigate("#LayoutUserPanel");
}

LayoutController.prototype.HideUserPanel = function (action) {
    var panel = $.mobile.activePage.find(".userpanel");
    panel.panel("close");
    App.Layout.UserPanelAction = action;
}

LayoutController.prototype.HideUserPanelDone = function () {
    this.IsUserPanelOpen = false;
    var action = App.Layout.UserPanelAction;
    App.Layout.UserPanelAction = null;
    App.Layout.ExecuteUserAction(action);
}

LayoutController.prototype.HideCartPanel = function () {
    var panel = $.mobile.activePage.find(".cartpanel");
    panel.panel("close");
}

LayoutController.prototype.HideCartPanelDone = function () {
    this.IsCartPanelOpen = false;
}

LayoutController.prototype.ExecuteUserAction = function (action) {
    switch (action) {
        case "UA-SALIR":
            this.LogOut(); break;
        case "UA-INGRESAR":
            App.Usuario.ShowIngresar(); break;
        case "UA-REGISTRARSE":
            App.Usuario.ShowRegistracion(); break;
        case "UA-HISTORIAL":
            App.Usuario.LoadPedidos(); break;
        case "UA-CUENTA":
            App.Usuario.LoadProfile(); break;
        case "UA-NOTIFICACIONES":
            App.Usuario.LoadAlerts(); break;
        case "UA-COMO":
            App.Info.ShowTutorial(); break;
        case "UA-FAQ":
            App.Info.ShowFAQ(); break;
        case "UA-TERMINOS":
            App.Info.ShowTerms(); break;
        case "UA-ADHERIR":
            App.Contacto.ShowRegisterStore(); break;
        case "UA-SUGERIR":
            App.Contacto.ShowSuggestStore(); break;
        case "UA-CONTACTO":
            App.Contacto.ShowContact(); break;
        case "UA-TEL":
            App.Contacto.Phone(); break;
        case "UA-BUSCAR":
            App.Home.Show(); break;
        case "UA-FAVORITOS":
            App.Buscar.Favorites(); break;
        case "UA-CHAT":
            App.Contacto.Chat(); break;
    }
}

LayoutController.prototype.UserAction = function (target) {
    action = $(target).data("action");
    if (!action) return;
    if (action == "UA-CHAT") {
        App.Layout.ExecuteUserAction(action);
        action = null;
    }
    this.HideUserPanel(action);
}

LayoutController.prototype.LogOut = function () {
    this.Dialog.Loading.Open();
    App.Authentication.LogOut(function () {
        App.Layout.Dialog.Loading.Close(function () {
            App.Layout.ShowToast("Se cerró tu sesión de usuario.");
            App.Home.Show();
        });
    });
}

LayoutController.prototype.ShowToast = function (msg, now) {
    if (now) {
        this.DisplayToastNotification(msg);
    }
    else {
        this.NextToastNotification = msg;
    }
}

LayoutController.prototype.DisplayNextToastNotification = function () {
    if (this.NextToastNotification) {
        this.DisplayToastNotification(this.NextToastNotification);
        this.NextToastNotification = null;
    }
}

LayoutController.prototype.DisplayToastNotification = function (msg) {
    var oToast = $("#ToastNotification");
    oToast.html(msg);
    oToast.delay(600).fadeIn('slow', function () { oToast.delay(2000 + (Math.floor(msg.length / 100) * 2000)).fadeOut('slow'); });
}

LayoutController.prototype.UpdateNotificationFlag = function () {
    var show = (App.Authentication.Current &&
        App.Authentication.Current.IsAuthenticated &&
        App.Authentication.Current.NotificationsCount &&
        (App.Authentication.Current.NotificationsCount > 0));
    var o = $(".header .options a .notif");
    if (!show) {
        o.hide();
    }
    else {
        o.show();
        if ((App.Authentication.Current.PrevNotificationsCount != undefined) &&
            (App.Authentication.Current.PrevNotificationsCount != null) &&
            (App.Authentication.Current.PrevNotificationsCount < App.Authentication.Current.NotificationsCount)) {
            var msg = "Tenés nuevas notificaciones disponibles"
            this.ShowToast(msg, true);
            if (App.IsMobileApp) {
                window.plugin.notification.local.cancelAll();
                window.plugin.notification.local.onclick = function (id, state, json) {
                    App.Usuario.LoadAlerts();
                };
                window.plugin.notification.local.add({
                    id: "RELIVERY-NOTIFICATION-UPDATE-FLAG",
                    title: "Relivery",
                    message: msg,
                    badge: App.Authentication.Current.NotificationsCount,
                    autoCancel: true,
                    //smallIcon: 'file:///favicon-160x160.png',
                    //icon: 'file:///favicon-160x160.png',
                    smallImage: 'appdata:mstile-144x144.png',
                    image: 'appdata:mstile-144x144.png',
                    wideImage: 'appdata:mstile-144x144.png'
                });
            }
        }
    }
}

//////////////////////// DIALOG CLASSES ////////////////////////
function LayoutControllerBaseDialog(id) {
    this.ID = id;
    this.Initialize();
}

LayoutControllerBaseDialog.prototype.Initialize = function () {
    $("#" + this.ID).popup();
}

LayoutControllerBaseDialog.prototype.Open = function () {
    $("#" + this.ID).popup('open', { transition: "fade", history: false });
}

LayoutControllerBaseDialog.prototype.Close = function (callback) {
    var id = "#" + this.ID;
    if (callback) {
        $(id).on("popupafterclose", function () {
            $(id).off("popupafterclose");
            setTimeout(function () { callback(); }, 200);
        });
    }
    setTimeout(function () { $(id).popup('close'); $(id).popup('close'); }, 50);
}


function LayoutControllerSearchingDialog() {
    LayoutControllerBaseDialog.call(this, "DialogsSearching");
}
LayoutControllerSearchingDialog.prototype = Object.create(LayoutControllerBaseDialog.prototype);
LayoutControllerSearchingDialog.prototype.constructor = LayoutControllerSearchingDialog;


function LayoutControllerLoadingDialog() {
    LayoutControllerBaseDialog.call(this, "DialogsLoading");
}
LayoutControllerLoadingDialog.prototype = Object.create(LayoutControllerBaseDialog.prototype);
LayoutControllerLoadingDialog.prototype.constructor = LayoutControllerLoadingDialog;


function LayoutControllerAlertDialog() {
    LayoutControllerBaseDialog.call(this, "DialogsAlert");
}
LayoutControllerAlertDialog.prototype = Object.create(LayoutControllerBaseDialog.prototype);
LayoutControllerAlertDialog.prototype.constructor = LayoutControllerAlertDialog;
LayoutControllerAlertDialog.prototype.Open = function (title, text, callback) {
    $("#DialogsAlert h1").text(title);
    var msg = text;
    if ($.isArray(text)) msg = text.join("<br />");
    $("#DialogsAlert p").html(msg);
    $("#DialogsAlert a").off("click").on("click", function () {
        App.Layout.Dialog.Alert.Close(function () {
            if (callback) callback();
        });
    });
    LayoutControllerBaseDialog.prototype.Open.call(this);
}


function LayoutControllerSelectDialog() {
    LayoutControllerBaseDialog.call(this, "DialogsSelect");
}
LayoutControllerSelectDialog.prototype = Object.create(LayoutControllerBaseDialog.prototype);
LayoutControllerSelectDialog.prototype.constructor = LayoutControllerSelectDialog;
LayoutControllerSelectDialog.prototype.Open = function (title, text, items, displayValue, callback) {
    $("#DialogsSelect h1").text(title);
    var msg = text;
    if ($.isArray(text)) msg = text.join("<br />");
    $("#DialogsSelect p").html(msg);
    var options = $("#DialogsSelect ul");
    options.empty();
    for (var i = 0; i < items.length; i++) {
        var newOption = $("<li><a href=\"#\"></a></li>");
        var link = newOption.find("a");
        link.text(items[i][displayValue]);
        link.click(items[i], function (e) {
            App.Layout.Dialog.Select.Close(function () {
                if (callback) callback(e);
            });
        });
        options.append(newOption);
    }
    LayoutControllerBaseDialog.prototype.Open.call(this);
}