﻿function Utils() {
    if (typeof Object.create !== 'function') {
        Object.create = function (o) {
            function F() { }
            F.prototype = o;
            return new F();
        };
    }
}

Utils.Alert = function (message) {
    alert(message);
}

Utils.String = {
    IsNullOrEmpty: function (value) {
        if (!value || value == null || value == "") return true;
        return false;
    },
    StartsWith: function(value, search) {
        if (Utils.String.IsNullOrEmpty(value) || Utils.String.IsNullOrEmpty(search)) return false;
        return (value.indexOf(search) == 0);
    }
}

Utils.GetPath = function (url) {
    if (Utils.String.IsNullOrEmpty(url)) return "";
    if (Utils.String.StartsWith(url, "/")) url = url.substr(1);
    return (App.BaseFilePath + url);
}

Utils.Array = {
    FindFirst: function (arr, property, value) {
        for (var i = 0; i < arr.length; i++) {
            if (arr[i][property] == value) {
                return arr[i];
            }
        }
        return null;
    }
}

Utils.UI = {
    Clear: {
        Checkbox: function (objs) {
            for (var i = 0; i < objs.length; i++) {
                var o = $(objs[i]);
                o.attr('checked', false);
                if (!(o.data("mobileCheckboxradio") === undefined)) {
                    o.checkboxradio("refresh");
                }
            }
        }
    },
    ListView: {
        Refresh: function (o) {
            if (!o) return;
            if (o.data("mobileListview")) {
                o.listview("refresh");
            }
        }
    },
    Checkbox: {
        Check: function (o) { Utils.UI.Checkbox.Update(o, true); },
        Uncheck: function (o) { Utils.UI.Checkbox.Update(o, false); },
        Update: function (o, value) {
            if (!o) return;
            value = value ? true : false;
            o.prop('checked', value).attr("checked", value);
            if (!(o.data("mobileCheckboxradio") === undefined)) {
                o.checkboxradio("refresh");
            }
            o.change();
        }
    },
    InitWatermark: function (id) {
        var o = $("#" + id);
        o.on("focusin", function () {
            var obj = $(this);
            var ph = $(this).data("placeholder");
            if (obj.val() == ph) obj.val("");
            o.removeClass("watermark");
        });
        o.on("focusout", function () {
            var obj = $(this);
            var ph = $(this).data("placeholder");
            if (obj.val() == "") {
                obj.val(ph);
                o.addClass("watermark");
            }
        });
        o.focusout();
    }
};

Utils.DataBind = function (data, containerId, triggerChange, hasToAppend, hasToUnwrap, templateId) {
    if (!templateId) {
        var id = "";
        if (containerId instanceof jQuery) {
            id = containerId.attr('id');
        }
        else {
            id = containerId;
        }
        templateId = id + "-Template";
    }
    var template = $("#" + templateId).html().trim();
    var markup = Mustache.render(template, data);
    markup = $.trim(markup);
    var res = $(markup);
    if (hasToUnwrap) res = res.children();
    var cont = null;
    if (containerId instanceof jQuery) {
        cont = containerId;
    }
    else {
        cont = $("#" + containerId);
    }
    if (!hasToAppend) cont.empty();
    cont.append(res);
    if (triggerChange) {
        cont.trigger("change");
    }
    else {
        cont.trigger("create");
    }
    return res;
}

Utils.GetData = function (url, params, callback, noErroHandler) {
    return Utils.RequestData(url, params, callback, false, noErroHandler);
}

Utils.PostData = function (url, params, callback, noErroHandler) {
    return Utils.RequestData(url, params, callback, true, noErroHandler);
}

Utils.RequestData = function (url, params, callback, isPost, noErroHandler) {
    return $.ajax({
        url: (App.BaseRequestPath + url),
        cache: false,
        data: params,
        dataType: "json",
        error: (noErroHandler ? null : function (o, status, error) {
            App.RequestErrorHandler(o, status, error);
            callback(false, { XHR: o, Status: status, Error: error });
        }),
        success: function (data) { callback(true, data); },
        timeout: 90000,
        traditional: true,
        type: (isPost ? "POST" : "GET")
    });
}

Utils.GeocodeLocation = function (city, address, callback) {
    var searchCity = city;
    if (searchCity.toLowerCase() == "capital federal") searchCity = "Capital Federal, Ciudad Autónoma de Buenos Aires";
    var address = address + ", " + searchCity + ", Argentina";
    var geocoder = new google.maps.Geocoder();
    geocoder.geocode(
        { 'address': address, 'region': 'AR' },
        function (results, status) {
            if (status == google.maps.GeocoderStatus.OK) {
                var res = new Array();
                for (var i = 0; i < results.length; i++) {
                    var item = Utils.IsValidGeocodeResult(results, i, city);
                    if (item.Result == true) res.push(item.Data);
                }
                if (res.length > 0) {
                    callback(true, res);
                    return;
                }
            }
            callback(false, null);
        }
    );
}

Utils.IsValidGeocodeResult = function (results, i, city) {
    if (city == "Capital Federal") {
        city = "(Ciudad Autónoma de Buenos Aires|Autonomous City of Buenos Aires|CF)";
    } else { city = ""; }
    var hasCountry = false;
    var hasCity = false;
    var street = "";
    var number = "";
    for (var ii = 0; ii < results[i].address_components.length; ii++) {
        if ($.inArray("country", results[i].address_components[ii].types) > -1 && results[i].address_components[ii].long_name == "Argentina" && results[i].address_components[ii].short_name == "AR") hasCountry = true;
        if ($.inArray("street_number", results[i].address_components[ii].types) > -1) number = results[i].address_components[ii].long_name;
        if ($.inArray("route", results[i].address_components[ii].types) > -1) street = results[i].address_components[ii].long_name;
        if (!($.inArray("route", results[i].address_components[ii].types) > -1) && city != "") {
            if (results[i].address_components[ii].long_name.match(new RegExp("(" + city + ")", "i")) || results[i].address_components[ii].short_name.match(new RegExp(city, "i"))) {
                hasCity = true;
            }
        }
        if ($.inArray("establishment", results[i].address_components[ii].types) > -1 && results[i].address_components[ii].long_name == "Aeroparque Internacional Jorge Newbery") {
            street = "Av. Rafael Obligado";
            number = "s/n";
        }
    }
    if (city == "") hasCity = true;
    if (hasCountry && hasCity && (street != "") && (number != "")) {
        return { Result: true, Data: { Street: street, Number: number, Address: (street + " " + number), Latitude: results[i].geometry.location.lat(), Longitude: results[i].geometry.location.lng()} };
    }
    return { Result: false };
}

Utils.GPSLocation = function (callback) {
    if (!navigator.geolocation) {
        callback(false, 0, 0);
        return;
    }
    var options = {
        enableHighAccuracy: true,
        maximumAge: 600000,
        timeout: 24000
    };
    navigator.geolocation.getCurrentPosition(
        function (position) { callback(true, position.coords.latitude, position.coords.longitude); },
        function () {
            options.enableHighAccuracy = false;
            navigator.geolocation.getCurrentPosition(
                function (position) { callback(true, position.coords.latitude, position.coords.longitude); },
                function () { callback(false, 0, 0); },
                options);
        },
        options);
}